==> jugg-agile-spring-boot-2.0-agile-spring-boot-20250815.071744-35-sources.jar: com/jugg/agile/spring/boot/dapper/JaDapperConfiguration.java <==
package com.jugg.agile.spring.boot.dapper;

import com.jugg.agile.framework.core.dapper.aspect.JaAspectOrder;
import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspect;
import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspectPointcut;
import com.jugg.agile.framework.core.dapper.aspect.JaNodeSpanResolver;
import com.jugg.agile.framework.core.dapper.log.JaLog;
import org.springframework.aop.aspectj.AspectJExpressionPointcutAdvisor;
import org.springframework.beans.factory.SmartInitializingSingleton;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.Resource;
import java.util.List;

@Configuration
@ConditionalOnProperty(name = JaDapperPropertyHandler.KeyDapperInit, havingValue = "true")
public class JaDapperConfiguration implements SmartInitializingSingleton {
    @Resource
    private List<JaNodeSpanResolver> resolverList;

    @Resource
    private List<JaDapperAspectPointcut> pointcutList;

    @Override
    public void afterSingletonsInstantiated() {
        JaNodeSpanResolver.Container.init(resolverList);
    }

    @Bean
    public AspectJExpressionPointcutAdvisor dapperAspect() {
        AspectJExpressionPointcutAdvisor advisor = new AspectJExpressionPointcutAdvisor();
        String expression = JaDapperAspectPointcut.Container.get(pointcutList);
        JaLog.info("dapperAspect pointcut : {}", expression);
        advisor.setExpression(expression);
        advisor.setOrder(JaAspectOrder.Dapper);
        advisor.setAdvice(new JaDapperAspect());
        return advisor;
    }
}

==> jugg-agile-spring-boot-2.6.13.0-agile-spring-boot-20250818.103035-3-sources.jar: com/jugg/agile/spring/boot/dapper/JaDapperConfiguration.java <==
package com.jugg.agile.spring.boot.dapper;

import com.jugg.agile.framework.core.dapper.aspect.JaAspectOrder;
import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspect;
import com.jugg.agile.framework.core.dapper.aspect.JaDapperAspectPointcut;
import com.jugg.agile.framework.core.dapper.aspect.JaNodeSpanResolver;
import com.jugg.agile.framework.core.dapper.log.JaLog;
import org.springframework.aop.aspectj.AspectJExpressionPointcutAdvisor;
import org.springframework.beans.factory.SmartInitializingSingleton;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.annotation.Resource;
import java.util.List;

@Configuration
@ConditionalOnProperty(name = JaDapperPropertyHandler.KeyDapperInit, havingValue = "true")
public class JaDapperConfiguration implements SmartInitializingSingleton {
    @Resource
    private List<JaNodeSpanResolver> resolverList;

    @Resource
    private List<JaDapperAspectPointcut> pointcutList;

    @Override
    public void afterSingletonsInstantiated() {
        JaNodeSpanResolver.Container.init(resolverList);
    }

    @Bean
    public AspectJExpressionPointcutAdvisor dapperAspect() {
//        if (JaStringUtil.isEmpty(dapperAspectExpression)) {
//
//        }
        AspectJExpressionPointcutAdvisor advisor = new AspectJExpressionPointcutAdvisor();
        String pointcut = JaDapperAspectPointcut.Container.get(pointcutList);
        JaLog.info("dapperAspect pointcut : {}", pointcut);
        advisor.setExpression(pointcut);
        advisor.setOrder(JaAspectOrder.Dapper);
        advisor.setAdvice(new JaDapperAspect());
        return advisor;
    }
}
